Plover Michela
==============

Michela (Italian system) support for Plover.


Documentation
-------------

For details about the theories and the contents of the dictionaries (in Italian):
* `Phonetic Theory <https://sillabix.gitbooks.io/dizionario-test/>`_
* `Orthographic Theory <https://www.gitbook.com/book/sillabix/dizionario-ortografico-michela-per-input-sillabic/details/>`_


Release history
---------------

0.1.5
~~~~~

* move punctuation and spacing entries to a dedicated dictionary
* add more entries to the commands dictionary
* add support for orthographic theory
* fix conflicting dictionary entries

0.1.4
~~~~~

* update main dictionary and split it into three parts: main, numbers, and commands

0.1.3
~~~~~

* fix undo stroke (use ``U``, not ``X``)

0.1.2
~~~~~

* add dictionaries
